@@ -25,6 +25,18 @@ mlx.getStructuralModel <- function() {
   return(r)
 }
 
+mlx.getTests <- function() {
+  r <- NULL
+  .hiddenCall(paste0('r <- lixoftConnectors::getTests()'))
+  return(r)
+}
+
+mlx.getSAEMiterations <- function() {
+  r <- NULL
+  .hiddenCall(paste0('r <- lixoftConnectors::getSAEMiterations()'))
+  return(r)
+}
+
 mlx.getPopulationParameterInformation <- function() {
   r <- NULL
   .hiddenCall(paste0('r <- lixoftConnectors::getPopulationParameterInformation()'))
@@ -95,8 +107,9 @@ mlx.getCovariateInformation <- function() {
   sn <- setdiff(r$name,names(r$covariate))
   if (length(sn)>0) {
     d <- mlx.getProjectSettings()$directory
-    p <- read.csv(file.path(d,"individualParameters/estimatedIndividualParameters.txt"))[,c("id",sn)]
-    r$covariate <- merge(r$covariate,p,by="id")
+    pind <- read.csv(file.path(d,"IndividualParameters/estimatedIndividualParameters.txt"))
+    if (all(sn %in% names(pind)))
+      r$covariate <- merge(r$covariate,pind[,c("id",sn)],by="id")
   }
   return(r)
 }
@@ -119,10 +132,10 @@ mlx.getEstimatedRandomEffects <- function() {
 mlx.getEstimatedStandardErrors <- function() {
   r <- NULL
   .hiddenCall(paste0('r <- lixoftConnectors::getEstimatedStandardErrors()'))
-  for (k in 1:length(r)) {
-    if (is.list(r[[k]]))
-      r[[k]] <- unlist(r[[k]])
-  }
+  # for (k in 1:length(r)) {
+  #   if (is.list(r[[k]]))
+  #     r[[k]] <- unlist(r[[k]])
+  # }
   return(r)
 }
 mlx.getGeneralSettings <- function() {
@@ -176,11 +189,11 @@ mlx.runConditionalModeEstimation <- function() {
 mlx.runStandardErrorEstimation <- function(linearization=NULL) {
   .hiddenCall(paste0('r <- lixoftConnectors::runStandardErrorEstimation(linearization = ',linearization,')'))
 }
-mlx.runScenario <- function(wait=TRUE) {
-  .hiddenCall(paste0('r <- lixoftConnectors::runScenario(wait = ',wait,')'))
+mlx.runScenario <- function() {
+  .hiddenCall('r <- lixoftConnectors::runScenario()')
 }
-mlx.setInitialEstimatesToLastEstimates <- function() {
-  .hiddenCall(paste0('r <- lixoftConnectors::setInitialEstimatesToLastEstimates()'))
+mlx.setInitialEstimatesToLastEstimates <- function(fixedEffectsOnly = F) {
+  .hiddenCall(paste0('r <- lixoftConnectors::setInitialEstimatesToLastEstimates(fixedEffectsOnly=fixedEffectsOnly)'))
 }
 
 mlx.setPopulationParameterInformation <- function(a) {
@@ -206,6 +219,9 @@ mlx.computePredictions <- function(a) {
 mlx.setCovariateModel <- function(a) {
   .hiddenCall(paste0('r <- lixoftConnectors::setCovariateModel(a)'))
 }
+mlx.setIndividualParameterModel <- function(a) {
+  .hiddenCall(paste0('lixoftConnectors::setIndividualParameterModel(a)'))
+}
 
 
 mlx.setCorrelationBlocks <- function(a) {
@@ -245,8 +261,14 @@ mlx.saveProject <- function(projectFile=NULL) {
   .hiddenCall(paste0('r <- lixoftConnectors::saveProject(projectFile = projectFile)'))
 }
 
-mlx.runPopulationParameterEstimation <- function() {
-  .hiddenCall(paste0('r <- lixoftConnectors::runPopulationParameterEstimation()'))
+mlx.runPopulationParameterEstimation <- function(parameters=NULL) {
+  r <- NULL
+  if (as.numeric(substr(packageVersion("lixoftConnectors"),1,4))>=2021 & !is.null(parameters))
+  .hiddenCall(paste0('r <- lixoftConnectors::runPopulationParameterEstimation(parameters=parameters)'))
+  else
+    .hiddenCall(paste0('r <- lixoftConnectors::runPopulationParameterEstimation()'))
+  .hiddenCall(paste0('r0 <- lixoftConnectors::runConditionalModeEstimation()'))
+  return(r)
 }
 
 mlx.runLogLikelihoodEstimation <- function(linearization = FALSE) {
